trident.layers package
======================

Submodules
----------

trident.layers.pytorch\_activations module
------------------------------------------

.. automodule:: trident.layers.pytorch_activations
   :members:
   :undoc-members:
   :show-inheritance:

trident.layers.pytorch\_blocks module
-------------------------------------

.. automodule:: trident.layers.pytorch_blocks
   :members:
   :undoc-members:
   :show-inheritance:

trident.layers.pytorch\_layers module
-------------------------------------

.. automodule:: trident.layers.pytorch_layers
   :members:
   :undoc-members:
   :show-inheritance:

trident.layers.pytorch\_normalizations module
---------------------------------------------

.. automodule:: trident.layers.pytorch_normalizations
   :members:
   :undoc-members:
   :show-inheritance:

trident.layers.pytorch\_pooling module
--------------------------------------

.. automodule:: trident.layers.pytorch_pooling
   :members:
   :undoc-members:
   :show-inheritance:

trident.layers.tensorflow\_activations module
---------------------------------------------

.. automodule:: trident.layers.tensorflow_activations
   :members:
   :undoc-members:
   :show-inheritance:

trident.layers.tensorflow\_blocks module
----------------------------------------

.. automodule:: trident.layers.tensorflow_blocks
   :members:
   :undoc-members:
   :show-inheritance:

trident.layers.tensorflow\_layers module
----------------------------------------

.. automodule:: trident.layers.tensorflow_layers
   :members:
   :undoc-members:
   :show-inheritance:

trident.layers.tensorflow\_normalizations module
------------------------------------------------

.. automodule:: trident.layers.tensorflow_normalizations
   :members:
   :undoc-members:
   :show-inheritance:

trident.layers.tensorflow\_pooling module
-----------------------------------------

.. automodule:: trident.layers.tensorflow_pooling
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: trident.layers
   :members:
   :undoc-members:
   :show-inheritance:
